@@ -699,7 +699,7 @@ class Chemical:
     def formula(self, formula):
         self._formula = str(formula)
         if self._Hf is None:
-            self._MW = compute_molecular_weight(self.atoms)
+            self.MW = compute_molecular_weight(self.atoms)
         else:
             self.reset_combustion_data()
     
@@ -1247,17 +1247,8 @@ class Chemical:
         self._kappa = kappa = thermal_conductivity_handle(None, ldata, gdata)
         
         # Surface tension
-        if Tb:
-            Hvap_Tb = Hvap.try_out(Tb)
-            if Hvap_Tb: Hvap_Tb /= MW
-            Cn_l = Cn.l.try_out(Tb)
-            if Cn_l: Cn_l /= MW
-            V_l = V.l.try_out(Tb, 101325.)
-            rho_l = fn.V_to_rho(V_l, MW) if V_l else None
-        else:
-            Hvap_Tb = Cn_l = rho_l = None
         data = (CAS, MW, Tb, Tc, Pc, Vc, Zc,
-                omega, self.Stiel_Polar, Hvap_Tb, rho_l, Cn_l)
+                omega, self.Stiel_Polar)
         self._sigma = sigma = surface_tension_handle(data)
         
         # Other
