@@ -126,11 +126,6 @@ class ThermoModel:
         if Tmin: self.Tmin = Tmin
         if Tmax: self.Tmax = Tmax
     
-    def load_data_from(self, data:dict):
-        isa = isinstance
-        for f in self.__dict__.values():
-            if isa(f, Functor): f.load_data_from(data)
-    
     def set_value(self, var, value):
         isa = isinstance
         for f in self.__dict__.values():
