@@ -50,6 +50,7 @@ References
         at the Normal Boiling Temperature of Pure Compounds Revisited."
         Fluid Phase Equilibria 106, no. 1-2 (May 1, 1995): 1–10.
         doi:10.1016/0378-3812(94)02627-D.
+
 """
 
 
@@ -71,8 +72,7 @@ from math import log, pi
 from .utils import CASDataReader, get_from_data_sources
 from .miscdata import organic_data_CRC, inorganic_data_CRC
 from .miscdata import VDI_saturation_dict, VDI_tabular_data
-from ..functional import Z
-from .coolprop import has_CoolProp, PropsSI, coolprop_dict, coolprop_fluids
+from .. import functional as fn
 from .dippr import DIPPR_EQ106
 
 read = CASDataReader(__file__, 'Phase Change')
@@ -242,7 +242,7 @@ def Clapeyron(T, Tc, Pc, V, Psat):
     """
     Tr = T/Tc
     P = Psat(T)
-    return R*T*Z(T, P, V.g(T, P))*log(Pc/P)/(1. - Tr)
+    return R*T*fn.Z(T, P, V.g(T, P))*log(Pc/P)/(1. - Tr)
 
 @Hvap(ref="[5]_ [6]_")
 def Pitzer(T, Tc, omega):
@@ -413,7 +413,8 @@ def Velasco(T, Tc, omega):
     --------
     From graph, in [10]_ for perfluoro-n-heptane.
     
-    >>> Velasco(333.2, 476.0, 0.5559)
+    >>> f = Velasco(476.0, 0.5559)
+    >>> f(333.2)
     33299.41734936356
     
     """
@@ -707,4 +708,3 @@ def heat_of_sublimation(CASRN, method='Any'):  # pragma: no cover
     
     '''
     return get_from_data_sources(sublimation_data_sources, CASRN, 'Hsub', method)
-
